@@ -18,13 +18,13 @@
 
 #pragma once
 
-#include <gtk/gtk.h>
+#include <adwaita.h>
 
 #include "screencast.h"
 
 #define SCREEN_CAST_TYPE_DIALOG (screen_cast_dialog_get_type ())
 G_DECLARE_FINAL_TYPE (ScreenCastDialog, screen_cast_dialog,
-                      SCREEN_CAST, DIALOG, GtkWindow)
+                      SCREEN_CAST, DIALOG, AdwWindow)
 
 ScreenCastDialog * screen_cast_dialog_new (const char            *app_id,
                                            ScreenCastSelection   *select,
