@@ -32,11 +32,13 @@
 #include <fcntl.h>
 
 #include <adwaita.h>
+#include <gxdp.h>
 
 #include <gio/gio.h>
 #include <gio/gdesktopappinfo.h>
 #include <gio/gunixfdlist.h>
 
+#include <glib-unix.h>
 #include <glib/gi18n.h>
 #include <locale.h>
 
@@ -48,6 +50,7 @@
 #include "background.h"
 #include "clipboard.h"
 #include "filechooser.h"
+#include "globalshortcuts.h"
 #include "lockdown.h"
 #include "print.h"
 #include "screenshot.h"
@@ -58,9 +61,8 @@
 #include "settings.h"
 #include "wallpaper.h"
 #include "dynamic-launcher.h"
-#include "externalwindow.h"
 #include "notification.h"
-
+#include "usb.h"
 
 static GMainLoop *loop = NULL;
 static GHashTable *outstanding_handles = NULL;
@@ -210,6 +212,19 @@ on_bus_acquired (GDBusConnection *connection,
       g_warning ("error: %s\n", error->message);
       g_clear_error (&error);
     }
+
+  if (!usb_init (connection, &error))
+    {
+      g_warning ("error: %s\n", error->message);
+      g_clear_error (&error);
+    }
+
+  if (!global_shortcuts_init (connection, &error))
+
+    {
+      g_warning ("error: %s\n", error->message);
+      g_clear_error (&error);
+    }
 }
 
 static void
@@ -230,38 +245,11 @@ on_name_lost (GDBusConnection *connection,
 }
 
 static gboolean
-init_gtk (GError **error)
+signal_handler_cb (gpointer user_data)
 {
-  GdkDisplay *display;
-
-  /* Avoid pointless and confusing recursion */
-#if GTK_CHECK_VERSION (4, 17, 1)
-  gtk_disable_portals ();
-#else
-  g_unsetenv ("GTK_USE_PORTAL");
-#endif
-
-  if (G_UNLIKELY (!g_setenv ("ADW_DISABLE_PORTAL", "1", TRUE)))
-    {
-      g_set_error (error, G_IO_ERROR, g_io_error_from_errno (errno),
-                   "Failed to set ADW_DISABLE_PORTAL: %s", g_strerror (errno));
-      return FALSE;
-    }
-
-  display = init_external_window_display (error);
-  if (!display)
-    return FALSE;
-
-  if (!gtk_init_check ())
-    {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-                   "Failed to initialize GTK");
-      return FALSE;
-    }
-
-  g_assert (gdk_display_get_default () == display);
-
-  return TRUE;
+  g_main_loop_quit (loop);
+  g_debug ("Terminated with signal.");
+  return G_SOURCE_REMOVE;
 }
 
 int
@@ -270,6 +258,7 @@ main (int argc, char *argv[])
   guint owner_id;
   g_autoptr(GError) error = NULL;
   GDBusConnection  *session_bus;
+  g_autoptr(GSource) signal_handler_source = NULL;
   g_autoptr(GOptionContext) context = NULL;
 
   setlocale (LC_ALL, "");
@@ -312,7 +301,7 @@ main (int argc, char *argv[])
       return 0;
     }
 
-  if (!init_gtk (&error))
+  if (!gxdp_init_gtk (GXDP_SERVICE_CLIENT_TYPE_PORTAL_BACKEND, &error))
     {
       g_debug ("Failed to initialize display server connection: %s",
                error->message);
@@ -330,6 +319,13 @@ main (int argc, char *argv[])
 
   loop = g_main_loop_new (NULL, FALSE);
 
+  /* Setup a signal handler so that we can quit cleanly.
+   * This is useful for triggering asan.
+   */
+  signal_handler_source = g_unix_signal_source_new (SIGHUP);
+  g_source_set_callback (signal_handler_source, G_SOURCE_FUNC (signal_handler_cb), NULL, NULL);
+  g_source_attach (signal_handler_source, g_main_loop_get_context (loop));
+
   outstanding_handles = g_hash_table_new (g_str_hash, g_str_equal);
 
   owner_id = g_bus_own_name (G_BUS_TYPE_SESSION,
